standalone_wizard_page — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# standalone_wizard_page

class `camelot.view.controls.standalone_wizard_page.` `StandaloneWizardPage`(window_title=None, parent=None, flags=<PyQt4.QtCore.WindowFlags object at 0x9e62ae4>)

  A Standalone Wizard Page Dialog for quick configuration windows

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus